OC.L10N.register(
    "settings",
    {
    "Private" : "私有",
    "Only visible to people matched via phone number integration through Talk on mobile" : "只对通过手机上Talk应用的电话号码整合功能匹配的人可见",
    "Local" : "本地",
    "Only visible to people on this instance and guests" : "仅对该实例上的人及来宾可见",
    "Federated" : "联合云",
    "Only synchronize to trusted servers" : "仅同步到受信任的服务器",
    "Published" : "已发布",
    "Synchronize to trusted servers and the global and public address book" : "同步到受信任的服务器以及全局和公共地址簿",
    "Verify" : "验证",
    "Verifying …" : "正在验证...",
    "Unable to change password" : "无法修改密码",
    "Very weak password" : "非常弱的密码",
    "Weak password" : "弱密码",
    "So-so password" : "一般强度的密码",
    "Good password" : "较强的密码",
    "Strong password" : "强密码",
    "Groups" : "分组",
    "Group list is empty" : "群组列表为空",
    "Unable to retrieve the group list" : "无法获取分组列表",
    "{actor} added you to group {group}" : "{actor} 将您加入分组 {group}",
    "You added {user} to group {group}" : "您将 {user} 加入分组 {group}",
    "{actor} added {user} to group {group}" : "{actor} 将 {user} 加入分组 {group}",
    "An administrator added you to group {group}" : "一个管理员将您加入分组 {group}",
    "An administrator added {user} to group {group}" : "一个管理员将 {user} 加入分组 {group}",
    "{actor} removed you from group {group}" : "{actor} 将您从分组 {group} 中移除",
    "You removed {user} from group {group}" : "您已将 {user} 从 群组 {group} 中移除",
    "{actor} removed {user} from group {group}" : "{actor} 将 {user} 从分组 {group} 中移除",
    "An administrator removed you from group {group}" : "管理员将您从分组 {group} 中移除",
    "An administrator removed {user} from group {group}" : "一个管理员将 {user} 从分组 {group} 中移除",
    "Your <strong>group memberships</strong> were modified" : "您的<strong>分组成员关系</strong>已被修改。",
    "{actor} changed your password" : "{actor} 已更改您的密码",
    "You changed your password" : "您已更改您的密码",
    "Your password was reset by an administrator" : "您的密码已被管理员重置",
    "Your password was reset" : "您的密码已重置",
    "{actor} changed your email address" : "{actor} 已更改您的电子邮件地址",
    "You changed your email address" : "您已更改您的电子邮件地址",
    "Your email address was changed by an administrator" : "您的电子邮件地址已被管理员更改",
    "You deleted app password \"{token}\"" : "您删除了应用密码 \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "您将应用密码 \"{token}\" 重命名为 \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "您将文件系统访问权限授予了应用密码 \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "您撤销了应用密码 \"{token}\" 的文件系统访问权限",
    "Security" : "安全",
    "You successfully logged in using two-factor authentication (%1$s)" : "您使用两步验证登录成功（%1$s）",
    "A login attempt using two-factor authentication failed (%1$s)" : "使用两步验证登录失败的尝试 (%1$s)",
    "Remote wipe was started on %1$s" : "%1$s上的远程擦除已开始",
    "Remote wipe has finished on %1$s" : "%1$s上的远程擦除已完成",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "您的 <strong>密码</strong> 或 <strong>邮箱</strong> 已被更改",
    "Apps" : "应用",
    "Could not remove app." : "无法移除应用。",
    "Could not update app." : "无法更新应用。",
    "Wrong password" : "密码错误",
    "Unable to change personal password" : "无法更改个人密码",
    "Saved" : "已保存",
    "No user supplied" : "未提供用户",
    "Unable to change password. Password too long." : "无法更改密码。密码太长。",
    "Authentication error" : "认证错误",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "请提供管理员恢复密码，否则所有用户的数据都将丢失。",
    "Wrong admin recovery password. Please check the password and try again." : "错误的管理员恢复密码。请检查密码并重试。",
    "Backend does not support password change, but the user's encryption key was updated." : "后端不支持密码修改，但用户的加密密钥已经更新。",
    "installing and updating apps via the App Store or Federated Cloud Sharing" : "通过应用商店或联合云共享安装和更新应用",
    "Federated Cloud Sharing" : "联合云共享",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL正使用一个过时的%1$s 版本 (%2$s)。请升级您的操作系统，否则像 %3$s 这样的特性将无法可靠地工作。",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "不能确定 cURL 的 TLS 版本是否已过时，因为在 HTTPS 请求 https://nextcloud.com 时发生了错误。请检查 nextcloud 日志文件以获取更多信息。",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "未加载 PHP OPcache 模块。为了更好的性能，建议将其加载到您的 PHP 安装中。",
    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache 已经禁用。为了更好的性能，建议在您的 PHP 设置中应用 <code>opcache.enable=1</code>。",
    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache 被设置为移除代码注释。当启用 OPcache 后，必须设置 <code>opcache.save_comments=1</code>，才能让 Nextcloud 工作。",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud 不被允许使用 OPcache API。启用 OPcache 后，强烈建议使用 <code>opcache.restrict_api</code> 包含所有 Nextcloud 目录，或取消该设置以禁用 OPcache API 限制，以避免 Nextcloud 核心或应用程序升级期间发生错误。",
    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud 不被允许使用 OPcache API。强烈建议使用 <code>opcache.restrict_api</code> 包含所有 Nextcloud 目录，或取消该设置以禁用 OPcache API 限制，以避免 Nextcloud 核心或应用程序升级期间发生错误。",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "几乎超过了 OPcache 键的最大数量。为确保所有脚本可以保留在缓存中，建议在您的 PHP 设置中 <code>opcache.max_accelerated_files</code> 设置一个高于 <code>%s</code> 的值。",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcache 缓存几乎已满。为确保所有脚本可以保留在缓存中，建议在您的 PHP 设置中 <code>opcache.memory_consumption</code> 设置一个高于 <code>%s</code> 的值。",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcache 内部字符串缓存几乎已满。为确保重复的字符串可以被有效地缓存，建议在您的 PHP 设置中 <code>opcache.interned_strings_buffer</code> 设置一个高于 <code>%s</code> 的值。",
    "Administrator documentation" : "管理员文档",
    "User documentation" : "用户文档",
    "Invalid SMTP password." : "无效的 SMTP 密码",
    "Email setting test" : "电子邮件设置测试",
    "Well done, %s!" : "已完成，%s！",
    "If you received this email, the email configuration seems to be correct." : "如果您收到了这封邮件，电子邮件配置应该就是正确的。",
    "Email could not be sent. Check your mail server log" : "邮件无法发送。检查您的邮件服务器日志",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "在发送电子邮件时出现问题。请修正您的设置。（错误：%s）",
    "You need to set your user email before being able to send test emails. Go to %s for that." : "您需要先前往%s设置电子邮箱，才能发送测试邮件。",
    "Users" : "用户",
    "Invalid user" : "无效用户",
    "Invalid mail address" : "无效的电子邮件地址",
    "Settings saved" : "设置已保存",
    "Unable to change full name" : "无法修改全名",
    "Unable to change email address" : "无法修改电子邮箱地址",
    "Unable to set invalid phone number" : "无法设置有效的电话号码",
    "Unable to set invalid website" : "无法设置无效的网站",
    "Some account data was invalid" : "一些账号数据无效",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "为了验证您的 Twitter 账号，请在 Twitter 上发布以下推文（请确保发布内容中没有任何换行符）：",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "为了验证您的网站，请将以下内容存储在“.well-known / CloudIdVerificationCode.txt”的网络根目录中（请确保完整的文本在一行中）：",
    "%1$s changed your password on %2$s." : "%1$s 更改了您在 %2$s 上的密码。",
    "Your password on %s was changed." : "您在 %s 上的密码已被更改。",
    "Your password on %s was reset by an administrator." : "您在 %s 上的密码已被管理员重置。",
    "Your password on %s was reset." : "您在 %s 上的密码已重置。",
    "Password for %1$s changed on %2$s" : "%2$s %1$s 的密码已更改",
    "Password changed for %s" : "%s 的密码已更改",
    "If you did not request this, please contact an administrator." : "如果这不是您发起的请求，请联系管理员。",
    "Your email address on %s was changed." : "您在 %s 上的电子邮件地址已更改。",
    "Your email address on %s was changed by an administrator." : "您在 %s 上的电子邮件地址已被管理员修改",
    "Email address for %1$s changed on %2$s" : "%2$s 上 %1$s 的电子邮件地址已更改",
    "Email address changed for %s" : "%s 的电子邮件地址已更改",
    "The new email address is %s" : "新的电子邮件地址是%s",
    "Your %s account was created" : "您的账号 %s 已创建",
    "Welcome aboard" : "欢迎使用",
    "Welcome aboard %s" : "%s，欢迎使用",
    "Welcome to your %s account, you can add, protect, and share your data." : "欢迎使用您的账号 %s ，您可以添加、保护和共享您的数据。",
    "Your username is: %s" : "您的用户名是：%s",
    "Set your password" : "设置您的密码",
    "Go to %s" : "访问 %s",
    "Install Client" : "安装客户端",
    "Logged in user must be a subadmin" : "当前登录用户必须为子管理员",
    "Settings" : "设置",
    "Personal" : "个人",
    "Administration" : "管理",
    "Additional settings" : "其他设置",
    "Administration privileges" : "管理权限",
    "Groupware" : "协作套件",
    "Overview" : "概览",
    "Basic settings" : "基本设置",
    "Sharing" : "共享",
    "Availability" : "可用性",
    "Calendar" : "日历",
    "Personal info" : "个人信息",
    "Mobile & desktop" : "手机与电脑",
    "Email server" : "电子邮件服务器",
    "Security & setup warnings" : "安全与设置警告",
    "Background jobs" : "后台任务",
    "Create" : "创建",
    "Change" : "修改",
    "Delete" : "删除",
    "Reshare" : "重新共享",
    "Unlimited" : "无限",
    "Verifying" : "正在验证",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "一个检查用户导入的 SSL 证书的后台工作正在进行中。请稍后再来检查。",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "目前存在一些用户导入的 SSL 证书，这在 Nextcloud 21 中已经不使用了。它们可以通过 \"occ security:certificates:import\" 命令在命令行导入。它们在数据目录下的路径如下所示。",
    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "LDAP 用户或组的 UUID 无效。请审查你在 LDAP 配置的专家部分的 \"覆盖 UUID 检测 \"设置，并使用 \"occ ldap:update-uuid\" 来更新它们。",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "旧的服务器端加密格式已启用。我们建议禁用此功能。",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "正在使用 MariaDB \"%s\" 版本。Nextcloud 21 及更新版本不再支持此版本，需要 MariaDB 10.2 或更高版本。",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "正在使用 MySQL 版本 \"%s\"。Nextcloud 21 及更新版本不再支持此版本，需要 MySQL 8.0 或 MariaDB 10.2 或更高版本。",
    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "正在使用 PostgreSQL \"%s\" 版本。Nextcloud 21 及更新版本不再支持此版本，需要 PostgreSQL 9.6 或更高版本。",
    "Profile information" : "个人信息",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "个人资料图片、全名、电子邮件、电话号码、地址、网站、Twitter、组织、角色、标题、个人简介以及您的个人资料是否启用",
    "Nextcloud settings" : "Nextcloud 设置",
    "Here you can decide which group can access certain sections of the administration settings." : "您可以在此决定哪个组可以访问管理设置的特定部分。",
    "None" : "无",
    "Unable to modify setting" : "无法更改设置",
    "Two-Factor Authentication" : "两步验证",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "两步验证可以对于所有用户和特定分组启用。如果没有设置两步验证提供者，他们则不能登录到系统。",
    "Enforce two-factor authentication" : "强制启用两步验证",
    "Limit to groups" : "限制于组",
    "Enforcement of two-factor authentication can be set for certain groups only." : "可以仅为某些组设置两步验证的强制执行。",
    "Two-factor authentication is enforced for all members of the following groups." : "两步验证对以下分组的所有成员强制启用。",
    "Enforced groups" : "强制群组",
    "Two-factor authentication is not enforced for members of the following groups." : "两步验证不对以下分组的成员强制启用。",
    "Excluded groups" : "排除群组",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "当分组被选择/排除时，将使用以下逻辑来确定一个用户是否强制启用两步验证：如果没有选择分组，两步验证将对被排除分组成员外的所有用户启用。如果选择了分组，两步验证将对被选择分组的成员启用。如果一个用户同时属于被选择和被排除分组，被选择分组将拥有优先权，两步验证将对该用户强制启用。",
    "Save changes" : "保存修改",
    "All" : "全部",
    "Limit app usage to groups" : "限制可使用应用的分组",
    "No results" : "没有结果",
    "Update to {version}" : "更新至 {version}",
    "Remove" : "移除",
    "Disable" : "禁用",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "该应用没有指定支持的 Nextcloud 最低版本。可能会在将来出现问题。",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "该应用没有指定支持的 Nextcloud 最高版本。可能会在将来出现问题。",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "无法安装应用，因为无法满足下列依赖：",
    "View in store" : "在商店中查看",
    "Visit website" : "访问网站",
    "Report a bug" : "报告问题",
    "Admin documentation" : "管理员文档",
    "Developer documentation" : "开发者文档",
    "This app is supported via your current Nextcloud subscription." : "根据您的 Nextcloud 订阅，此应用受到支持。",
    "Supported" : "受支持",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "特色应用由社区并在社区内开发。 它们提供了中心功能，并准备投入生产使用。",
    "Featured" : "精选",
    "Update to {update}" : "更新至 {update}",
    "All apps are up-to-date." : "所有的应用程序都是最新的。",
    "Results from other categories" : "来自其他类别的结果",
    "No apps found for your version" : "未找到适合当前版本的应用",
    "Disable all" : "禁用全部",
    "Enable all" : "启用所有",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n 应用有可用的更新"],
    "_Update_::_Update all_" : ["全部更新"],
    "Marked for remote wipe" : "标记为远程擦除",
    "Device settings" : "设备设置",
    "Allow filesystem access" : "允许访问文件系统",
    "Rename" : "重命名",
    "Revoke" : "撤销",
    "Wipe device" : "擦除设备",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "如果您的设备还没有开始擦除，撤销这个令牌可能会阻止擦除它。",
    "Internet Explorer" : "IE 浏览器",
    "Edge" : "Edge 浏览器",
    "Firefox" : "火狐浏览器",
    "Google Chrome" : "谷歌浏览器",
    "Safari" : "Safari 浏览器",
    "Google Chrome for Android" : "安卓版谷歌浏览器",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "{productName} iOS app" : "{productName} iOS 应用",
    "{productName} Android app" : "{productName} 安卓应用",
    "{productName} Talk for iOS" : "{productName}iOS版通话应用",
    "{productName} Talk for Android" : "{productName}Android版通话应用",
    "Sync client - {os}" : "同步客户端 - {os}",
    "This session" : "当前会话",
    "Device" : "设备",
    "Last activity" : "最后活跃",
    "Devices & sessions" : "设备和活动链接",
    "Web, desktop and mobile clients currently logged in to your account." : "您账号当前登录的网页版，桌面和移动客户端。",
    "Do you really want to wipe your data from this device?" : "您真的要从此设备擦除您的数据吗？",
    "Confirm wipe" : "确认擦除",
    "Error while creating device token" : "创建设备令牌时出错",
    "Error while updating device token scope" : "更新设备令牌范围时出错",
    "Error while updating device token name" : "更新设备令牌名称时出错",
    "Error while deleting the token" : "删除令牌时出错",
    "Error while wiping the device with the token" : "使用令牌擦除设备时出错",
    "App name" : "应用名",
    "Create new app password" : "创建新应用密码",
    "Use the credentials below to configure your app or device." : "使用下述证书配置您的应用或设备。",
    "For security reasons this password will only be shown once." : "由于安全原因，密码仅会显示一次。",
    "Username" : "用户名",
    "Password" : "密码",
    "Done" : "完成",
    "Show QR code for mobile apps" : "为移动应用展示二维码",
    "Copied!" : "已复制！",
    "Copy" : "复制",
    "Could not copy app password. Please copy it manually." : "无法复制应用密码。请手动复制。",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "为了使服务器正常工作，正确配置后台作业是很重要的。Cron 是推荐的设置。更多信息请参见文档。",
    "Last job execution ran {time}. Something seems wrong." : "上次任务执行于 {time}。但似乎有些问题。",
    "Last job ran {relativeTime}." : "上次任务执行于 {relativeTime}。",
    "Background job did not run yet!" : "后台任务从未执行！",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single user instance." : "每加载一个页面就执行一个任务。使用场景：单一用户实例。",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php 注册在一个 webcron 服务上，每 5 分钟通过 HTTP 调用 cron.php。使用场景：非常小的实例（1-5 个用户，取决于使用情况）。",
    "Cron (Recommended)" : "Cron（推荐）",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "为了运行该功能，您需要 PHP posix 扩展。请参考 {linkstart}PHP 文档{linkend} 获取更多信息。",
    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "使用系统 cron 服务，每 5 分钟调用 cron.php 文件。建议在所有实例中使用。",
    "The cron.php needs to be executed by the system user \"{user}\"." : "cron.php 需要由系统用户 \"{user}\" 执行。",
    "Unable to update background job mode" : "无法更新后台任务模式",
    "Profile" : "个人资料",
    "Enable or disable profile by default for new users." : "对新用户默认启用或禁用简介。",
    "Enable" : "启用",
    "Unable to update profile default setting" : "无法更新个人资料默认设置",
    "Server-side encryption" : "服务器端加密",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "服务器端加密可以加密上传到此服务器的文件。这带来了诸如性能损失的限制，因此仅在需要时启用此功能。",
    "Enable server-side encryption" : "启用服务器端加密",
    "Please read carefully before activating server-side encryption:" : "在激活服务器端加密之前，请仔细阅读：",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "一旦加密被启用，之后上传到服务器的所有文件都将服务器上加密。只有当启用状态的加密模块支持解密并且所有前提都满足时（例如：设定恢复密钥）才能解除加密。",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "单独的加密不能保证系统的安全性。请参考加密应用工作原理和支持的用例的文档获取更多信息。",
    "Be aware that encryption always increases the file size." : "请注意，加密会增加文件大小。",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "定期备份数据有助于保证数据完整，并且确保备份您的加密数据和加密密钥。",
    "This is the final warning: Do you really want to enable encryption?" : "这是最后一次警告：您确定要启用加密？",
    "No encryption module loaded, please enable an encryption module in the app menu." : "没有加载加密模块，请在 APP 应用菜单中启用加密模块。",
    "Select default encryption module:" : "选择默认的加密模块：",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "您需要从旧版本（ownCloud <= 8.0）迁移您的加密密钥。请在应用中启用 \"Default encryption module\" 并运行 {command}",
    "Unable to update server side encryption config" : "无法更新服务端加密设置",
    "Rename group" : "重命名分组",
    "Remove group" : "删除分组",
    "You are about to remove the group {group}. The users will NOT be deleted." : "您将要移除群组 {group}。组中的用户不会被删除。",
    "Please confirm the group removal " : "请确认移除群组",
    "Current password" : "当前密码",
    "New password" : "新密码",
    "Change password" : "修改密码",
    "Your profile picture" : "您的个人资料图片",
    "Upload profile picture" : "上传个人资料图片",
    "Remove profile picture" : "移除个人资料图片",
    "Picture provided by original account" : "初始账号提供的图片",
    "Cancel" : "取消",
    "Set as profile picture" : "设置为个人资料图片",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "请注意，您的个人资料图片可能需要24小时才能在所有地方更新完成。",
    "Choose your profile picture" : "选择您的个人资料图片",
    "Please select a valid png or jpg file" : "请选择有效的 png 或 jpg 文件",
    "Error setting profile picture" : "设置个人资料图片出错 ",
    "Error cropping profile picture" : "剪裁个人资料图片出错",
    "Error saving profile picture" : "保存个人资料图片出错",
    "Error removing profile picture" : "移除个人资料图片出错",
    "Your biography" : "个人简介",
    "Details" : "详情",
    "You are a member of the following groups:" : "您是以下群组的成员：",
    "You are using <strong>{usage}</strong>" : "您已使用<strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "您已使用 <strong>{totalSpace}</strong> 中的 <strong>{usage}</strong> (<strong>{usageRelative}%</strong>)",
    "Your full name" : "您的全名",
    "Email options" : "电子邮件选项",
    "Primary email for password reset and notifications" : "用于重设密码和通知的主邮件",
    "Remove primary email" : "删除主邮件地址",
    "Delete email" : "删除电子邮件",
    "Unset as primary email" : "取消设为主邮件地址",
    "This address is not confirmed" : "此地址未经确认",
    "Set as primary email" : "设为主电子邮件地址",
    "Your email address" : "您的电子邮件",
    "Additional email address {index}" : "附加邮件地址 {index}",
    "Unable to delete primary email address" : "无法删除主电邮地址",
    "Unable to update primary email address" : "无法更新主电邮地址",
    "Unable to add additional email address" : "无法新增附加电邮地址",
    "Unable to update additional email address" : "无法更新附加电邮地址",
    "Unable to delete additional email address" : "无法删除附加电邮地址",
    "No email address set" : "尚未设置 Email 地址",
    "Additional emails" : "附加邮箱地址",
    "Your headline" : "您的标题",
    "Language" : "语言",
    "Help translate" : "帮助翻译",
    "Unable to update language" : "无法更新语言",
    "No language set" : "没有设置语言",
    "Locale" : "地区语系",
    "Week starts on {firstDayOfWeek}" : "每周开始于 {firstDayOfWeek}",
    "Unable to update locale" : "无法更新语系",
    "No locale set" : "没有设置语系",
    "Your location" : "您的位置",
    "Your organisation" : "您的组织",
    "Your phone number" : "您的电话号码",
    "Edit your Profile visibility" : "编辑个人资料可见性",
    "Enable Profile" : "编辑个人资料",
    "Unable to update profile enabled state" : "无法更新个人资料启用状态",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "系统将遵循个人资料的 “可见性” 和 “范围” 设置中限制更严格那个。例如，当 “可见性” 设置为 “显示给所有人”，而 “范围” 设置为 “私密” 时，系统将按照 “私密” 来设置您个人资料",
    "Unable to update visibility of {displayId}" : "无法更新 {displayId} 的可见性",
    "Your role" : "您的角色",
    "Your Twitter handle" : "您的 Twitter 账号",
    "Your website" : "您的网站",
    "No {property} set" : "没有设置 {property}",
    "Unable to update {property}" : "无法更新 {property}",
    "Change scope level of {property}, current scope is {scope}" : "更改 {property} 的范围级别，当前范围为 {scope}",
    "Unable to update federation scope of the primary {property}" : "无法更新主要 {property} 的联盟范围",
    "Unable to update federation scope of additional {property}" : "无法更新额外 {property} 的联盟范围",
    "Add additional email" : "添加额外的电子邮箱",
    "Add" : "添加",
    "You do not have permissions to see the details of this user" : "您没有权限查看该用户的详细信息",
    "Add new password" : "添加新的密码",
    "Add new email address" : "添加新的电子邮件地址",
    "Add user to group" : "添加用户到组",
    "Set user as admin for" : "设置用户为管理员",
    "Select user quota" : "选择用户容量限额",
    "Toggle user actions menu" : "切换用户行动菜单",
    "Delete user" : "删除用户",
    "Wipe all devices" : "擦除所有设备",
    "Disable user" : "禁用用户",
    "Enable user" : "启用用户",
    "Resend welcome email" : "重新发送欢迎邮件",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "如果设备丢失或退出组织，这可以从与 {userid} 关联的所有设备中远程擦除 Nextcloud 数据。 仅当设备连接到互联网时才有效。",
    "Remote wipe of devices" : "远程擦除设备",
    "Wipe {userid}'s devices" : "擦除 {userid} 的设备",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "完全删除 {userid} 的账号，包括其所有个人文件，应用程序数据等。",
    "Account deletion" : "帐号删除",
    "Delete {userid}'s account" : "删除 {userid} 的账号",
    "Welcome mail sent!" : "欢迎邮件已经发送！",
    "Edit User" : "编辑用户",
    "{size} used" : "已使用 {size}",
    "New user" : "新建用户",
    "Will be autogenerated" : "将自动生成",
    "Display name" : "显示名称",
    "Email" : "电子邮件",
    "Default language" : "默认语言",
    "Add a new user" : "添加新用户",
    "Avatar" : "头像",
    "Group admin for" : "分组管理员",
    "Quota" : "配额",
    "User backend" : "用户来源",
    "Storage location" : "存储位置",
    "Last login" : "最后登录",
    "No users in here" : "这里没有用户",
    "Default quota" : "默认配额",
    "Common languages" : "常用语言",
    "Other languages" : "其他语言",
    "Password change is disabled because the master key is disabled" : "密码修改被禁用，因为主密码被禁用",
    "Passwordless authentication requires a secure connection." : "无密码身份验证需要安全的连接。",
    "Add WebAuthn device" : "添加 WebAuthn 设备",
    "Please authorize your WebAuthn device." : "请授权您的 WebAuthn 设备。",
    "Name your device" : "为您的设备命名",
    "Adding your device …" : "正在添加您的设备...",
    "Server error while trying to add WebAuthn device" : "尝试添加 WebAuthn 设备时出现服务器错误",
    "Server error while trying to complete WebAuthn device registration" : "尝试完成 WebAuthn 设备注册时出现服务器错误",
    "Unnamed device" : "未命名的设备",
    "Passwordless Authentication" : "无密码认证",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "遵循 FIDO2 标准为无密码身份验证设置您的账号。",
    "No devices configured." : "未配置任何设备。",
    "The following devices are configured for your account:" : "为您的帐户配置了以下设备：",
    "Your browser does not support WebAuthn." : "您的浏览器不支持 WebAuthn。",
    "Your apps" : "您的应用",
    "{license}-licensed" : "{license}-许可协议",
    "Changelog" : "更改日志",
    "by {author}\n{license}" : "按照 {author}\n{license}",
    "Enter group name" : "输入群组名称",
    "Add group" : "添加分组",
    "Active users" : "活跃用户",
    "Admins" : "管理员",
    "Disabled users" : "已禁用的用户",
    "Default quota:" : "默认配额：",
    "Select default quota" : "选择默认存储限额",
    "Show Languages" : "显示语言",
    "Show last login" : "显示最后登录",
    "Show user backend" : "显示用户来源",
    "Show storage path" : "显示存储路径",
    "Send email to new user" : "发送电子邮件给新用户",
    "Not saved" : "未保存",
    "Sending…" : "正在发送…",
    "Email sent" : "邮件已发送",
    "Location" : "位置",
    "Profile picture" : "个人头像",
    "About" : "关于",
    "Full name" : "全名",
    "Additional email" : "附加邮箱",
    "Headline" : "标题",
    "Organisation" : "组织",
    "Phone number" : "电话号码",
    "Role" : "角色",
    "Twitter" : "Twitter",
    "Fediverse (e.g. Mastodon)" : "联邦宇宙（例如Mastodon）",
    "Website" : "网站",
    "Profile visibility" : "个人资料可见性",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "不可用，因为包括文件共享和日历邀请在内的核心功能需要此属性",
    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "您的账号上的联合云功能已被停用，如有疑问，请咨询系统管理员。",
    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "不可用，因为不允许将特定于用户的数据发布到查找服务器，如果有任何问题，请与系统管理员联系",
    "Active apps" : "已启用的应用",
    "Disabled apps" : "已禁用的应用",
    "Updates" : "更新",
    "App bundles" : "应用捆绑包",
    "Featured apps" : "精选应用",
    "Show to everyone" : "显示给所有人",
    "Show to logged in users only" : "仅显示给登录用户",
    "Hide" : "隐藏",
    "Download and enable" : "下载并启用",
    "Enable untested app" : "启用未经测试的应用",
    "The app will be downloaded from the App Store" : "将从应用商店下载应用",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "此应用被标记为与您的 Nextcloud 版本不兼容。如果您要继续，您仍可安装此应用。请注意此应用可能不会正常工作。",
    "Never" : "从不",
    "An error occurred during the request. Unable to proceed." : "请求期间发生错误。无法继续。",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "该应用已启用，但是需要更新。5秒后将跳转到更新页面。",
    "Error: This app cannot be enabled because it makes the server unstable" : "错误:这个应用程序不能被启用，因为它使服务器不稳定 ",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "您的网络请求过多。如果出现错误，请稍后重试或与您的管理员联系。",
    "Documentation" : "文档",
    "Forum" : "论坛",
    "Login" : "登录",
    "SSL/TLS" : "SSL/TLS",
    "Open documentation" : "打开文档",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "设置此服务器以能够发送电子邮件（例如密码重置和通知）非常重要。",
    "Send mode" : "发送模式",
    "Encryption" : "加密",
    "Sendmail mode" : "邮件发送模式",
    "From address" : "来自地址",
    "Server address" : "服务器地址",
    "Port" : "端口",
    "Authentication method" : "认证方法",
    "Authentication required" : "需要认证",
    "Credentials" : "证书",
    "SMTP Username" : "SMTP 用户名",
    "SMTP Password" : "SMTP 密码",
    "Save" : "保存",
    "Test and verify email settings" : "测试并验证电子邮箱设置",
    "Send email" : "发送电子邮件",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "您的每项配置对于实例的安全性和性能都至关重要。 为了帮助您，我们正在做一些自动检查。 有关详细信息，请参阅文档链接。",
    "All checks passed." : "所有检查已通过。",
    "There are some errors regarding your setup." : "关于您的设置有一些错误。",
    "There are some warnings regarding your setup." : "关于您的设置有一些警告。",
    "Checking for system and security issues." : "正在检查系统和安全问题。",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "请仔细检查<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">安装指南↗</a>，并检查<a href=\"%2$s\">日志</a>中是否有错误或警告。",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "通过<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">我们的安全检查 ↗</a>检查您 Nextcloud 的安全",
    "Version" : "版本",
    "You need to enable the File sharing App." : "您需要启用 File 共享应用",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "作为管理员，您可以调整共享行为。 有关详细信息，请参阅文档。",
    "Allow apps to use the Share API" : "允许应用使用共享 API",
    "Set default expiration date for shares" : "设置共享的默认截止日期",
    "Expire after" : "过期于下列日期后",
    "day(s)" : "天",
    "Enforce expiration date" : "强制过期日期",
    "Set default expiration date for shares to other servers" : "为共享给其他服务器的文件设置默认到期日",
    "Allow users to share via link and emails" : "允许用户通过链接和电子邮件分享 ",
    "Allow public uploads" : "允许公开上传",
    "Always ask for a password" : "一直要求输入密码",
    "Enforce password protection" : "强制密码保护",
    "Exclude groups from password requirements:" : "从密码要求中排除指定组：",
    "Set default expiration date" : "设置默认到期日",
    "Exclude groups from creating link shares:" : "禁止指定组创建链接分享：",
    "Allow resharing" : "允许二次共享",
    "Allow sharing with groups" : "允许群组共享",
    "Restrict users to only share with users in their groups" : "限制用户只与他们组中的用户共享",
    "Exclude groups from sharing" : "在共享中排除组",
    "These groups will still be able to receive shares, but not to initiate them." : "这些组将仍可以获取共享，但无法向他人共享。",
    "Allow username autocompletion to users based on phone number integration" : "允许基于手机号码集成自动完成用户的用户名",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "如果启用了“同组”自动完成和“手机号码集成”，则匹配两者中的任何一个都足以显示用户",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "输入全名或电子邮箱地址时，允许自动完成（忽略缺少的通讯录匹配及同组要求）",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "在公开链接上传页中显示免责声明。（仅当文件列表隐藏时显示。）",
    "This text will be shown on the public link upload page when the file list is hidden." : "这些内容将在公开链接上传页中当文件列表隐藏时显示。",
    "Default share permissions" : "默认共享权限",
    "Reasons to use Nextcloud in your organization" : "在您的组织中使用 Nextcloud 的原因",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "由{communityopen}Nextcloud社区{linkclose}开发，{githubopen}源代码{linkclose}基于 {licenseopen}AGPL{linkclose}许可协议。",
    "Like our Facebook page" : "点赞我们 facebook 页面！",
    "Follow us on Twitter" : "在 Twitter 上关注我们！",
    "Follow us on Mastodon" : "在Mastodon上关注我们",
    "Check out our blog" : "浏览我们的博客！",
    "Subscribe to our newsletter" : "订阅我们的最新消息！",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Nextcloud 的这个社区版本不受支持，即时通知不可用。",
    "Use a second factor besides your password to increase security for your account." : "使用除您密码之外的第二种方法来增强您账号的安全性。",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "如果您使用第三方应用程序连接到 Nextcloud，请确保在启用第二因素身份验证之前为每个应用程序创建和配置应用程序密码。",
    "An error occurred while changing your language. Please reload the page and try again." : "修改您的语言时遇到错误。请重新载入页面后再试。",
    "An error occurred while changing your locale. Please reload the page and try again." : "修改您的地区时遇到错误。请重新载入页面后再试。",
    "Select a profile picture" : "选择个人头像",
    "Week starts on {fdow}" : "周开始于 {fdow}",
    "You created app password \"{token}\"" : "您创建了应用密码 \"{token}\"",
    "An administrator created app password \"{token}\"" : "管理员创建了应用密码 \"{token}\"",
    "Couldn't remove app." : "无法删除应用。",
    "Couldn't update app." : "无法更新应用。",
    "Backend doesn't support password change, but the user's encryption key was updated." : "后端不支持密码更改，但用户的加密密钥已更新。",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "不能确定 cURL 的 TLS 版本是否已过时，因为在HTTPS请求 https://nextcloud.com 时发生了错误。请检查 nextcloud 日志文件以了解详情。",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "几乎超过了 OPcache 键的最大数量。为确保所有脚本可以保留在缓存中，建议在您的 PHP 设置中 <code>opcache.max_accelerated_files</code> 设置一个高于 <code>%s</code> 的值。",
    "Admin privileges" : "管理员特权",
    "Unable to update biography" : "无法更新小传",
    "Unable to update full name" : "无法更新全名",
    "No full name set" : "未设置全名",
    "Unable to update headline" : "无法更新标题",
    "Unable to update organisation" : "无法更新组织",
    "Unable to update role" : "无法更新角色",
    "Change scope level of {accountProperty}" : "更改 {accountProperty} 的范围",
    "Unable to update federation scope of the primary {accountProperty}" : "无法更新主 {accountProperty} 的联盟范围",
    "Unable to update federation scope of additional {accountProperty}" : "无法更新附加 {accountProperty} 的联盟范围",
    "Migration in progress. Please wait until the migration is finished" : "正在进行迁移。请稍等，直到迁移完成",
    "Migration started …" : "迁移开始...",
    "Address" : "地址",
    "An error occured during the request. Unable to proceed." : "请求期间发生错误。 无法继续。",
    "Plain" : "明文",
    "NT LAN Manager" : "NT LAN 管理器",
    "STARTTLS" : "STARTTLS",
    "Please read carefully before activating server-side encryption: " : "在激活服务器端加密之前，请仔细阅读：",
    "Enable encryption" : "启用加密",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "您需要从旧版本（ownCloud <= 8.0）迁移您的加密密钥。请在应用中启用 \\\"Default encryption module\\\" 并运行 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "您需要从旧版本（ownCloud<=8.0）迁移您的加密密钥。",
    "Start migration" : "开始迁移",
    "Last job execution ran %s. Something seems wrong." : "上次定时任务执行于：%s。但存在一些问题。",
    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "某些任务自 %s 以来尚未执行。 请考虑增加执行频率。",
    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "自 %s 以来，有些作业没有执行。 请考虑切换到系统计划任务。",
    "Last job ran %s." : "上次定时任务执行于：%s。",
    "Background job didn’t run yet!" : "后台任务当前没有运行！",
    "For the server to work properly, it's important to configure background jobs correctly. \"Cron\" is the recommended setting. Please see the documentation for more information." : "为了使服务器正常工作，正确配置后台作业是很重要的。\"Cron\" 是推荐的设置。更多信息请参见文档。",
    "Pick background job setting" : "选择后台任务设置",
    "Recommended" : "推荐",
    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php 需要被系统用户 \"%s\" 执行。",
    "Allow username autocompletion in share dialog" : "在分享对话框中允许用户名自动完成",
    "Allow username autocompletion to users within the same groups" : "允许自动完成同一组内的用户的用户名",
    "Change privacy level of profile picture" : "更改个人头像的隐私级别",
    "Upload new" : "上传",
    "Select from Files" : "选择文件",
    "Remove image" : "删除图片",
    "png or jpg, max. 20 MB" : "png 或 jpg 格式，最大 20MB",
    "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "请注意，头像可能需要24小时才能在所有地方更新完成。",
    "Choose as profile picture" : "选择个人头像",
    "You are using <strong>%s</strong>" : "您已经使用了 <strong>%s</strong> 存储空间",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "您正在使用 <strong>%1$s</strong> ，来自 <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Change privacy level of phone number" : "更改电话号码的隐私级别",
    "Change privacy level of address" : "更改地址的隐私级别",
    "Your postal address" : "您的邮寄地址",
    "Change privacy level of website" : "更改网站的隐私级别",
    "It can take up to 24 hours before the account is displayed as verified." : "在账号显示为已验证之前最多可能需要 24 小时。",
    "Link https://…" : "链接 https://…",
    "Change privacy level of Twitter profile" : "更改推特资料的隐私权限",
    "Twitter handle @…" : "Twitter 用户名 @…",
    "Choose profile picture from files" : "从文件中选择个人资料图片"
},
"nplurals=1; plural=0;");
